@@ -1,5 +1,5 @@
 /*  ADCD - A Diminutive CD player for Linux/GNU
-    Copyright (C) 2004-2015 Antonio Diaz Diaz.
+    Copyright (C) 2004-2016 Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@ namespace {
 
 const char * const Program_name = "Adcd";
 const char * const program_name = "adcd";
-const char * const program_year = "2015";
+const char * const program_year = "2016";
 const char * invocation_name = 0;
 
 
@@ -54,6 +54,7 @@ void show_help()
                "  -i, --info              display info about current status and exit\n"
                "  -o, --open              open tray and exit\n"
                "  -p, --play[=<n>]        start playing at track <n> (default 1) and exit\n"
+               "  -p, --play=[+-]         change to next/previous track and exit\n"
                "  -s, --stop              stop playing and exit\n"
                "  -u, --pause             pause/resume playing and exit\n"
                "  -v, --volume[=[+-]<n>]  show, adjust or set volume and exit\n"
@@ -113,8 +114,8 @@ void show_error( const char * const msg, const int errcode = 0,
     {
     std::fprintf( stderr, "%s: %s", program_name, msg );
     if( errcode > 0 )
-      std::fprintf( stderr, ": %s.", std::strerror( errcode ) );
-    std::fprintf( stderr, "\n" );
+      std::fprintf( stderr, ": %s", std::strerror( errcode ) );
+    std::fputc( '\n', stderr );
     }
   if( help )
     std::fprintf( stderr, "Try '%s --help' for more information.\n",
@@ -129,7 +130,7 @@ int main( const int argc, const char * argv[] )
 //  const char * mixer_dev_name = "/dev/mixer";
   enum Volcommand { vnone, vadjust, vset, vshow };
   Volcommand vc = vnone;
-  int track = 1, volume = 0;
+  int step = 0, track = 1, volume = 0;
   bool open_tray = false, close_tray = false;
   bool info = false, pause = false, play = false, stop = false;
   invocation_name = argv[0];
@@ -165,7 +166,10 @@ int main( const int argc, const char * argv[] )
       case 'i': info = true; break;
 //      case 'm': mixer_dev_name = arg; break;
       case 'o': open_tray = true; break;
-      case 'p': play = true; if( arg[0] ) track = std::strtol( arg, 0, 0 ); break;
+      case 'p': if( arg[0] == '+' ) step = 1;
+                else if( arg[0] == '-' ) step = -1;
+                else { play = true; if( arg[0] ) track = std::strtol( arg, 0, 0 ); }
+                break;
       case 's': stop = true; break;
       case 'u': pause = true; break;
       case 'v': if( !arg[0] ) vc = vshow;
@@ -212,6 +216,14 @@ int main( const int argc, const char * argv[] )
         return 1; }
     interactive = false;
     }
+  if( step )
+    {
+    const bool done = ( step > 0 ) ? cd.next_track() : cd.prev_track();
+    if( !done )
+      { show_error( cd.tracks() ? "can't change track." : cd.status_name() );
+        return 1; }
+    interactive = false;
+    }
   if( info ) { cd.show_info(); interactive = false; }
   if( pause ) { cd.pause(); interactive = false; if( info ) cd.show_info(); }
 
